@@ -1,4 +1,4 @@
-# Copyright (c) 2015 Intel Corporation
+# Copyright (c) 2014 Mirantis Inc.
 # Copyright (c) 2015 ISPRAS
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -17,17 +17,16 @@
 from sahara import conductor
 from sahara import context
 from sahara.plugins.cdh import abstractversionhandler as avm
-from sahara.plugins.cdh.v5_4_0 import cloudera_utils as cu
-from sahara.plugins.cdh.v5_4_0 import config_helper as c_helper
-from sahara.plugins.cdh.v5_4_0 import deploy as dp
-from sahara.plugins.cdh.v5_4_0 import edp_engine
-from sahara.plugins.cdh.v5_4_0 import plugin_utils as pu
-from sahara.plugins.cdh.v5_4_0 import validation as vl
-
+from sahara.plugins.cdh.v5_3_0 import cloudera_utils as cu
+from sahara.plugins.cdh.v5_3_0 import config_helper as c_helper
+from sahara.plugins.cdh.v5_3_0 import deploy as dp
+from sahara.plugins.cdh.v5_3_0 import edp_engine
+from sahara.plugins.cdh.v5_3_0 import plugin_utils as pu
+from sahara.plugins.cdh.v5_3_0 import validation as vl
 
 conductor = conductor.API
-CU = cu.ClouderaUtilsV540()
-PU = pu.PluginUtilsV540()
+CU = cu.ClouderaUtilsV530()
+PU = pu.PluginUtilsV530()
 
 
 class VersionHandler(avm.AbstractVersionHandler):
@@ -66,11 +65,8 @@ class VersionHandler(avm.AbstractVersionHandler):
             "SOLR": ['SOLR_SERVER'],
             "SQOOP": ['SQOOP_SERVER'],
             "SENTRY": ['SENTRY_SERVER'],
-            "KMS": ['KMS'],
             "YARN_GATEWAY": [],
-            "HDFS_GATEWAY": [],
-            "JOURNALNODE": ['HDFS_JOURNALNODE'],
-            "STANDBYRESOURCEMANAGER": ['YARN_STANDBYRM']
+            "HDFS_GATEWAY": []
         }
 
     def validate(self, cluster):
